/**************************/
/* Source of net calendar */
/**************************/

#include <stdio.h>
#include <Bitmap.h>
#include "NetCountCalendar.h"
#include "Counter.h"
#include "CalendarWinPref.h"
#include "NetCountCalendarDatas.h"


/**** datas global ****/
NetCountCalendarDatas *calendar_datas;

/************************************************/
/********** BControl NetCountCalendar ***********/
/************************************************/
/**** constructor of control class ****/
NetCountCalendar::NetCountCalendar(BPoint point,const char *name, BMessage *message,NetCountCalendarDatas *datas)
:BControl(BRect(point.x,point.y,point.x+269,point.y+260),name,NULL,message,B_FOLLOW_NONE,B_WILL_DRAW| B_PULSE_NEEDED)
{
	size_t	taille;
	const void	*image;

	SetFontSize(10.0);

	_popupprices = NULL;
	_listexterne = true;
	calendar_datas = datas;
	if(datas==NULL)
	{
		_listexterne = false;
		calendar_datas = new NetCountCalendarDatas();
	}
	for(int i=0;i<7;i++)
		(calendar_datas->DaysList()).MoveInto(_dayslist[i],i*3,3);

	_setup = new BBitmap(BRect(0,0,15,15),B_CMAP8);
	image = ((CounterApp *)be_app)->resApp.LoadResource('BBMP',"PREF_CAL_BTMP",&taille);
	_setup->SetBits((char *)image+146,512,0,B_CMAP8);
	
	_heure = new BBitmap(BRect(0,0,9,8),B_CMAP8);
	image = ((CounterApp *)be_app)->resApp.LoadResource('BBMP',"INFO_CAL_BTMP",&taille);
	_heure->SetBits((char *)image+143,180,0,B_CMAP8);
	
	PlaceBitmapTime();
	
	calendar_datas->ChangedList();
	_winprefcalendar = NULL;
	BuildMenu();
}

/**** Destructor of control class ****/
NetCountCalendar::~NetCountCalendar(void)
{
	BMessenger(_winprefcalendar).SendMessage(B_QUIT_REQUESTED);
				
	delete _heure;
	delete _setup;
	delete _popupprices;
	if(_listexterne!=true)
		delete calendar_datas;
}

/**** Draw methode of control ****/
void NetCountCalendar::Draw(BRect frame)
{
	char		buffer[5];
	BString		listofdays;
	time_t		origin_t;
	time_t		date_t;
	tm			date;		
	
	origin_t = time(0);
	date = *localtime(&origin_t);
	origin_t -= (date.tm_wday * 86400 + date.tm_hour * 3600 + date.tm_min * 60 + date.tm_sec);
	
	// draw days
	for(int i=0;i<7;i++)
		DrawHeader(BRect(25+i*35,0,59+i*35,19),&_dayslist[i]);
	
	// draw hours
	SetHighColor(0,0,0,255);
	SetLowColor(ViewColor());		
	for(int i=0;i<24;i++)
	{	
		sprintf(buffer,"%02d",i);
		DrawString(buffer,BPoint(8,i*10+29));
	}
	
	// draw calendar colors
	for(int j=0;j<7;j++)
	{
		date_t = origin_t + j*86400 - 3600; 
		for(int i=0;i<24;i++)
		{	
			date_t += 3600; 
			date = *localtime(&date_t);
			SetHighColor(calendar_datas->NetItemColor(date));	
			FillRect(BRect(j*35+26,i*10+21,j*35+59,i*10+29));
		}
	}

	// draw option button
	SetHighColor(109,109,109);
	StrokeRect(BRect(0,0,24,19));
	SetHighColor(255,255,255);
	StrokeLine(BPoint(1,1),BPoint(23,1));
	StrokeLine(BPoint(1,1),BPoint(1,18));
	SetHighColor(165,165,165);
	StrokeLine(BPoint(23,2),BPoint(23,17));
	StrokeLine(BPoint(2,18),BPoint(23,18));
	DrawBitmap(_setup,BPoint(5,2));

	// draw bitmap time/hour
	DrawBitmap(_heure,_heureplace);
}

/**** function to draw an header informations for listview ****/
void NetCountCalendar::DrawHeader(BRect frame,BString *title)
{
	int			stringleft;
	int			stringtop;
	font_height	height;
	rgb_color	oldcolor;
	
	oldcolor = HighColor();
	GetFontHeight(&height);
	stringleft = (int)StringWidth(title->String());
	stringleft = (int)((frame.right - frame.left - stringleft)/2 + frame.left -1);
	stringtop = (int)(height.ascent + /*height.descent + */height.leading);
	stringtop = (int)((frame.bottom - frame.top + stringtop)/2 + frame.top -1);

	SetHighColor(160,160,160);
	StrokeRect(BRect(frame.left,frame.top,frame.right-1,frame.bottom-1));
	SetHighColor(255,255,255);
	StrokeRect(BRect(frame.left+1,frame.top+1,frame.right,frame.bottom));
	SetHighColor(110,110,110);
	StrokeRect(frame);
	SetHighColor(0,0,0);

	DrawString(title->String(),BPoint(stringleft,stringtop));
	SetHighColor(oldcolor);	
}

/**** Mouse down - open preferences windows or fix tariff ****/
void NetCountCalendar::MouseDown(BPoint Point)
{
	uint32	buttons = 0;
	uint32	index = 0;
	uint32	indextab = 0;
	BPoint	control;

	//control = Point;
	GetMouse(&control,&buttons);
	if ((buttons & B_PRIMARY_MOUSE_BUTTON) || (buttons & B_SECONDARY_MOUSE_BUTTON))
	{	
		if (control.x<25 && control.y<21)
		{
			BMessage	openWin(OPEN_WIN_PREF);
			BMessenger(this).SendMessage(&openWin);
		}
		else if (buttons & B_SECONDARY_MOUSE_BUTTON)
		{
			BuildMenu();
			ConvertToScreen(&Point);
			BMenuItem *selected = _popupprices->Go(Point);
			if (selected)
			{
				index = _popupprices->IndexOf(selected);
				if (control.x<25 && control.y>21)
					calendar_datas->SetRowTo((int32)((control.y-21)/10),index);
				else if (control.x>24 && control.y<22)
					calendar_datas->SetColTo((int32)((control.x-24)/35),index);
				else
				{
					indextab = (int)((control.x-24)/35) + 7 * (int)((control.y-21)/10);
					(calendar_datas->DatasList())[indextab] = index;
				}
				Invalidate();
			}
		}		
	}
}

/**** Build the popup menu for prices ****/
void NetCountCalendar::BuildMenu()
{
	NetCountCalendarItem	*priceitem;
	BList					*listofprices;	
	uint32					nbitems;	
	
	if(calendar_datas->ListIsChanged())
	{
		if(_popupprices != NULL)
			delete _popupprices;
	
		_popupprices = new BPopUpMenu("List-Prices");
		listofprices = calendar_datas->PricesList();
		nbitems = listofprices->CountItems();
		for(uint32 i=0;i<nbitems;i++)
		{
			priceitem = (NetCountCalendarItem*)listofprices->ItemAt(i);
			_popupprices->AddItem(new CColorMenuItem(priceitem->ItemColor(), priceitem->ItemName(), NULL));
		}
	}
}
/**** MessageReceived ****/
void NetCountCalendar::MessageReceived(BMessage *msg)
{
	switch(msg->what)
	{
		/* close the setting window of netcalendar */	
		case OPEN_WIN_PREF:
			OpenWinPref();
			break;
		case CLOSE_WIN_PREF:
			{
			BRect	framefenetre;
			
			if(msg->FindRect("fenetre-pref-netcalendar",&framefenetre) == B_OK)
				calendar_datas->SetWinFrame(framefenetre);
			_winprefcalendar = NULL;
			}
			break;
		default:
			BControl::MessageReceived(msg);
	}
}

/**** Open the window of preferences ****/
void NetCountCalendar::OpenWinPref()
{	
	if(_winprefcalendar==NULL)
	{
		_winprefcalendar= new CalendarWinPref(calendar_datas->WinFrame(),BMessenger(this));
		_winprefcalendar->Show();
	}
	else
		_winprefcalendar->Activate();
}

/**** Pulse for adjuste the place of Bitmap time ****/
void NetCountCalendar::Pulse()
{
	PlaceBitmapTime();
}

/**** function for calculate position of Bitmap time ****/
void NetCountCalendar::PlaceBitmapTime()
{
	float 	x,y;
	time_t	temptime;
	tm		timeplace;		
	
	temptime = time(0);
	timeplace = *localtime(&temptime);
	
	if(((_heureplace.y-21)/10 != timeplace.tm_hour) || ((_heureplace.x-50)/35 != timeplace.tm_wday))
	{
		Invalidate(BRect(_heureplace.x,_heureplace.y,_heureplace.x+10,_heureplace.y+9));
		x = timeplace.tm_wday * 35 + 50;
		y = timeplace.tm_hour * 10 + 21;	
		_heureplace.Set(x,y);
		Invalidate(BRect(_heureplace.x,_heureplace.y,_heureplace.x+10,_heureplace.y+9));
	}
}