/**********************/
/*	HistoryWindow.cpp */
/**********************/
#include <stdio.h>
#include "HistoryWindow.h"
#include "Counter.h"

/*******************/
/*  history window */
/*******************/
/**** Constructor ****/
HistoryWindow::HistoryWindow(BRect frame,const char *name,BMessenger messenger)
: BWindow(frame,name, B_TITLED_WINDOW, B_NOT_RESIZABLE | B_NOT_ZOOMABLE )
{
	BRect				tabRect;
	BRect				tabViewRect;
	BTab				*listtab;
	BView				*aView;
	BFont				viewFont;

	_app = (CounterApp *)be_app;

	SetLook(B_FLOATING_WINDOW_LOOK);
	SetFeel(B_NORMAL_WINDOW_FEEL);
	
	aView = new BView(Bounds(),"support-view",B_FOLLOW_ALL_SIDES, B_WILL_DRAW);
	aView->SetViewColor(219,219,219,255);
	aView->SetFontSize(10.0);
	
	tabViewRect = Bounds();
	tabViewRect.bottom -= 30;

	_historyTabView = new CTabView(tabViewRect,"HistoryTabView");
	tabRect = _historyTabView->Bounds();
	tabRect.bottom -= _historyTabView->TabHeight();

	listtab = new BTab();
	_viewdetails = new HistoryView(tabRect,DETAILS,messenger);
	_historyTabView->AddTab(_viewdetails,listtab);
	listtab->SetLabel(_app->Langage("detail-view"));
	
	listtab = new BTab();
	_viewpermonth = new HistoryView(tabRect,PER_MONTH,messenger);
	_historyTabView->AddTab(_viewpermonth,listtab);
	listtab->SetLabel(_app->Langage("month-view"));
	
	AddChild(aView);
	aView->GetFont(&viewFont);
	aView->AddChild(_historyTabView);

	// add TextView for visualisation of total time and price
	_timeTextView = new BTextView(BRect(5,208,132,228),"total-time",BRect(0,5,190,20),B_FOLLOW_NONE,B_WILL_DRAW);
	_timeTextView->SetViewColor(219,219,219,255);
	_timeTextView->SetFontAndColor(&viewFont);
	_timeTextView->MakeSelectable(false);
	_timeTextView->MakeEditable(false);

	_priceTextView = new BTextView(BRect(133,208,249,228),"total-price",BRect(0,5,189,20),B_FOLLOW_NONE,B_WILL_DRAW);
	_priceTextView->SetViewColor(219,219,219,255);
	_priceTextView->SetFontAndColor(&viewFont);
	_priceTextView->MakeSelectable(false);
	_priceTextView->MakeEditable(false);

	// Add Button to Add connections   
   	_addconnections = new BButton(BRect(251,206,310,220), "b-add-connection",_app->Langage("button-add"),new BMessage(U_ADD_HISTORY_ITEM));
    _addconnections->SetEnabled((_app->AddState() == B_CONTROL_ON));

	// Add Button to Remove connections    
   	_rmconnections = new BButton(BRect(315,206,370,220), "b-remove-connection",_app->Langage("button-remove"),new BMessage(U_RM_HISTORY_ITEM));
    _rmconnections->SetEnabled(false);

   	aView->AddChild(_addconnections);
   	aView->AddChild(_rmconnections);
   	aView->AddChild(_timeTextView);
   	aView->AddChild(_priceTextView);

	RefreshTotal();
}

/**** destructor ****/
HistoryWindow::~HistoryWindow()
{
}

/**** Message received ****/
void HistoryWindow::MessageReceived(BMessage *message)
{
	switch(message->what)
	{
		// Message to set the state of Remove button
		case U_SELECT_CTAB_MSG:
		case U_SELECT_CONNVIEW:
			{
			bool	selectedList;
			
			message->FindBool("list-select",&selectedList);
		    _rmconnections->SetEnabled(selectedList & (_app->RemoveState() == B_CONTROL_ON));
			}
			break;
		// Message to Add and Remove connections
		case U_ADD_HISTORY_ITEM:
		case U_RM_HISTORY_ITEM:
			(BMessenger((_historyTabView->TabAt(_historyTabView->Selection()))->View())).SendMessage(message);
			break;
		case U_REFRESH_ALL_COUNT:
			RefreshTotal();
			break;
		default:
			BWindow::MessageReceived(message);
	}
}

/**** quit requested ****/
bool HistoryWindow::QuitRequested(void)
{
	BRect		framefenetre = Frame();
	BMessage	msgtoclose(CLOSE_WIN_HISTORY);
	
	msgtoclose.AddRect("fenetre-history",framefenetre);
	BMessenger(((CounterApp *)be_app)->aWindow).SendMessage(&msgtoclose);

	return(true);
}

/**** Refresh time and price view ****/
void HistoryWindow::RefreshTotal()
{
	static char	totaltext[20];
	int32		h,m,s;

	h = _app->TotalTime() / 3600;
	m = (_app->TotalTime() % 3600) / 60;
	s = _app->TotalTime() % 60;
	_totalString.SetTo(_app->Langage("total-surf"));
	sprintf(totaltext,"%02ld:%02ld:%02ld",h,m,s);
	_totalString << totaltext;
	_timeTextView->SetText(_totalString.String());

	_totalString.SetTo(_app->Langage("total-price"));
	sprintf(totaltext,"%.2f",_app->TotalPrice());
	_totalString << totaltext;
	_priceTextView->SetText(_totalString.String());
}