/***************************************************/
/* vue pour fixer les preferences de l'application */
/***************************************************/
#include "PrefAppView.h"
#include "PrefAllViews.h"
#include <ScrollView.h>

/**** Constructor ****/
PrefAppView::PrefAppView(BRect frame)
: BView(frame,"view-pref-app",B_FOLLOW_ALL_SIDES, B_WILL_DRAW)
{
	BRect 		aRect(Bounds());
	BView		*tmpview;
	BTab		*listtab;

	SetViewColor(219,219,219,255);
	SetFontSize(10.0);

	aRect.top += 10;
	aRect.left += 10;
	aRect.right /= 3;
	aRect.bottom -= 10;
	
	_listofprefs = new BListView(aRect,"list-of-preferences",B_SINGLE_SELECTION_LIST,B_FOLLOW_LEFT | B_FOLLOW_TOP,B_WILL_DRAW);
	_listofprefs->SetSelectionMessage(new BMessage(U_SELECT_VIEW_MSG));
	
	aRect.left = aRect.right + 25;
	aRect.right = (BRect(Bounds())).right - 7;
	_prefviews = new PTabView(aRect,"tabs-views",_listofprefs);

	/*** reglage des options de l'application ***/
	tmpview = new ApplicationSettingView(Bounds());
	listtab = new BTab(tmpview);
	_prefviews->AddTab(tmpview,listtab);

	/*** reglages des couleurs etc ... ***/
	tmpview = new DisplaySettingView(Bounds());
	listtab = new BTab(tmpview);
	_prefviews->AddTab(tmpview,listtab);

	/*** reglage des parametre pour l'historique ***/
	tmpview = new HistorySettingView(Bounds());
	listtab = new BTab(tmpview);
	_prefviews->AddTab(tmpview,listtab);

	/*** reglage des parametre pour ancienne version ***/
	tmpview = new OldSettingView(Bounds());
	listtab = new BTab(tmpview);
	_prefviews->AddTab(tmpview,listtab);

	/*** reglage des parametre pour ancienne version ***/
	tmpview = new BackupSettingView(Bounds());
	listtab = new BTab(tmpview);
	_prefviews->AddTab(tmpview,listtab);

	AddChild(new BScrollView("scrollPrefListView",_listofprefs,B_FOLLOW_LEFT | B_FOLLOW_TOP,0,false,true));
	AddChild(_prefviews);
}

/**** Destructor ****/
PrefAppView::~PrefAppView(void)
{
}

/**** messages ****/
void PrefAppView::MessageReceived(BMessage *msg)
{
	switch(msg->what)
	{
		case U_SELECT_VIEW_MSG:
			SelectView();
			break;
		case U_REFRESH_SETTINGS_MSG:
			((PTabView *)_prefviews)->SelectTab(1);
			break;
		default:
			BView::MessageReceived(msg);
	}
}

void PrefAppView::AttachedToWindow()
{
	// attachement de la liste des vues
	_listofprefs->SetTarget(this);
	// select the first item
	_listofprefs->MakeFocus(true);
	_listofprefs->Select(0);

	
	BView::AttachedToWindow();
}

void PrefAppView::SelectView()
{

	int32	itemCourant;
	
	itemCourant = _listofprefs->CurrentSelection();
	if(itemCourant >= 0)
		((PTabView *)_prefviews)->SelectTab(itemCourant);
}
